@@ -8,14 +8,14 @@
 
 
 
-LoginPrompt::LoginPrompt(MaemoApplicationHandler *handler,QWidget *parent) :
+LoginPrompt::LoginPrompt(MaemoApplicationHandler *handler,int w,QWidget *parent) :
     QWidget(parent),
     ui(new Ui::LoginPrompt)
 {
     ui->setupUi(this);
     ui->saveItCheckBox->setVisible(false);
     ui->userNameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase);
-
+    id=w;
     applicationHandler = handler;
 }
 
@@ -65,7 +65,7 @@ void LoginPrompt::loginResponse(int res) {
             QMaemo5InformationBox::information(parentWidget(),"\n"+username+", you are logged in successfully!\n");
         #endif
         emit loggedIn (username);
-        this->close();
+        emit deleteWidget (id);
     }
     else if (res == MaemoApplicationHandler::LoggedInCredentialsError) {
         #ifdef Q_WS_MAEMO_5
@@ -80,3 +80,8 @@ void LoginPrompt::loginResponse(int res) {
         qDebug () << "connection error";
     }
 }
+
+void LoginPrompt::closeWidget() {
+    this->close();
+    emit deleteWidget (id);
+}
